@@ -89,7 +89,7 @@
 #'
 #' @export
 fks <- function (FKFobj) {
-  if (class(FKFobj) != 'fkf') stop('Input must be an object of class FKF')
+  if ( !inherits(FKFobj,'fkf') ) stop('Input must be an object of class FKF')
   if (FKFobj$status[1] != 0 || FKFobj$status[2] != 0) {
     stop('Smoothing requires successful inversion of Ft for all t')
   }
@@ -103,7 +103,7 @@ fks <- function (FKFobj) {
   Zt <- FKFobj$Zt
   Tt <- FKFobj$Tt
 
-
+  
   ans <- .Call("FKS", yt, Zt, vt, Tt, Kt, Ftinv, at, Pt, PACKAGE = "FKF")
   return(ans)
 }
